==> yawp-1.20.1-fabric-0.6.2-beta1-sources.jar: de/z0rdak/yawp/api/permission/FlagPermissions.java <==
package de.z0rdak.yawp.api.permission;

import de.z0rdak.yawp.api.events.region.FlagCheckEvent;
import de.z0rdak.yawp.api.events.region.FlagCheckResult;
import de.z0rdak.yawp.core.flag.FlagState;
import de.z0rdak.yawp.core.flag.RegionFlag;
import de.z0rdak.yawp.platform.Services;
import org.jetbrains.annotations.Nullable;

import java.util.function.Consumer;
import net.minecraft.class_1657;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_5321;

import static de.z0rdak.yawp.api.FlagEvaluator.processCheck;

public class FlagPermissions {

    public static FlagState checkFlagPermission(class_2338 pos, RegionFlag flag, class_5321<class_1937> dim) {
        return checkFlagPermission(pos, flag, dim, null, null);
    }

    public static FlagState checkFlagPermission(class_2338 pos, RegionFlag flag, class_5321<class_1937> dim, @Nullable Consumer<FlagCheckResult> onDeny) {
        return checkFlagPermission(pos, flag, dim, null, onDeny);
    }

    public static FlagState checkFlagPermission(class_2338 pos, RegionFlag flag, class_5321<class_1937> dim, @Nullable Consumer<FlagCheckResult> onAllow, @Nullable Consumer<FlagCheckResult> onDeny) {
        FlagCheckEvent checkEvent = new FlagCheckEvent(pos, flag, dim);
        if (Services.EVENT.post(checkEvent)) {
            return FlagState.UNDEFINED;
        }
        return processCheck(checkEvent, onAllow, onDeny);
    }

    public static FlagState checkPlayerFlagPermission(RegionFlag flag, class_2338 pos, class_5321<class_1937> dim, class_1657 player, @Nullable Consumer<FlagCheckResult> onAllow, @Nullable Consumer<FlagCheckResult> onDeny) {
        FlagCheckEvent checkEvent = new FlagCheckEvent(pos, flag, dim, player);
        if (Services.EVENT.post(checkEvent)) {
            return FlagState.UNDEFINED;
        }
        return processCheck(checkEvent, onAllow, onDeny);
    }

    public static FlagState checkPlayerFlagPermission(RegionFlag flag, class_2338 pos, class_5321<class_1937> dim, class_1657 player) {
        return checkPlayerFlagPermission(flag, pos, dim, player, null, null);
    }

    public static FlagState checkPlayerFlagPermission(RegionFlag flag, class_2338 pos, class_5321<class_1937> dim, class_1657 player, @Nullable Consumer<FlagCheckResult> onDeny) {
        return checkPlayerFlagPermission(flag, pos, dim, player, null, onDeny);
    }
}

==> yawp-1.21.4-fabric-0.5.2-beta1-sources.jar: de/z0rdak/yawp/api/permission/FlagPermissions.java <==
package de.z0rdak.yawp.api.permission;

import de.z0rdak.yawp.api.events.region.FlagCheckEvent;
import de.z0rdak.yawp.api.events.region.FlagCheckResult;
import de.z0rdak.yawp.core.flag.FlagState;
import de.z0rdak.yawp.core.flag.RegionFlag;
import de.z0rdak.yawp.platform.Services;
import org.jetbrains.annotations.Nullable;

import java.util.function.Consumer;
import net.minecraft.class_1657;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_5321;

import static de.z0rdak.yawp.handler.HandlerUtil.processCheck;

public class FlagPermissions {

    public static FlagState checkFlagPermission(class_2338 pos, RegionFlag flag, class_5321<class_1937> dim) {
        return checkFlagPermission(pos, flag, dim, null, null);
    }

    public static FlagState checkFlagPermission(class_2338 pos, RegionFlag flag, class_5321<class_1937> dim, @Nullable Consumer<FlagCheckResult> onDeny) {
        return checkFlagPermission(pos, flag, dim, null, onDeny);
    }

    public static FlagState checkFlagPermission(class_2338 pos, RegionFlag flag, class_5321<class_1937> dim, @Nullable Consumer<FlagCheckResult> onAllow, @Nullable Consumer<FlagCheckResult> onDeny) {
        FlagCheckEvent checkEvent = new FlagCheckEvent(pos, flag, dim);
        if (Services.EVENT.post(checkEvent)) {
            return FlagState.UNDEFINED;
        }
        return processCheck(checkEvent, onAllow, onDeny);
    }

    public static FlagState checkPlayerFlagPermission(RegionFlag flag, class_2338 pos, class_5321<class_1937> dim, class_1657 player, @Nullable Consumer<FlagCheckResult> onAllow, @Nullable Consumer<FlagCheckResult> onDeny) {
        FlagCheckEvent checkEvent = new FlagCheckEvent(pos, flag, dim, player);
        if (Services.EVENT.post(checkEvent)) {
            return FlagState.UNDEFINED;
        }
        return processCheck(checkEvent, onAllow, onDeny);
    }

    public static FlagState checkPlayerFlagPermission(RegionFlag flag, class_2338 pos, class_5321<class_1937> dim, class_1657 player) {
        return checkPlayerFlagPermission(flag, pos, dim, player, null, null);
    }

    public static FlagState checkPlayerFlagPermission(RegionFlag flag, class_2338 pos, class_5321<class_1937> dim, class_1657 player, @Nullable Consumer<FlagCheckResult> onDeny) {
        return checkPlayerFlagPermission(flag, pos, dim, player, null, onDeny);
    }
}
